@@ -25,6 +25,9 @@
 int main() {
 	proccpuinfo *info = proccpuinfo_read();
 
+	if (!info)
+		return 1;
+
 	printf("architecture\t\t: %s\n",info->architecture);
 	printf("hardware_platform\t: %s\n",info->hardware_platform);
 	printf("frequency\t\t: %lf MHz\n", info->frequency);
