@@ -18,13 +18,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#define _VERSION (6)
+
 #include "proccpuinfo.h"
 
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-
+char *__proccpuinfo_get_cputype();
 char *__proccpuinfo_get_value(int target_key);
 int __proccpuinfo_get_count(int target_key);
 char *proccpuinfo_filename = NULL;
@@ -55,7 +57,7 @@ enum {
 
 struct proccpuinfo_arch_list_t {
         const char *name;
-	unsigned char architecture[3];
+	unsigned char architecture[4];
 	unsigned char hardware_platform[3];
 	char freq_delim;
 	unsigned char frequency[3];
@@ -65,25 +67,25 @@ struct proccpuinfo_arch_list_t {
 	unsigned char cpus;
 	unsigned char bogomips[4];
 } proccpuinfo_archlist[] = {
-	{ "i386",		{31,15, 0}, {41,30, 0}, '\0', {16, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 2, 0, 0} },
-	{ "x86_64",		{31, 0, 0}, {41, 0, 0}, '\0', {16, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "ia64",		{23, 0, 0}, {40, 0, 0}, '\0', {16, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 1, 0, 0, 0} },
-	{ "alpha",		{19, 0, 0}, {36, 0, 0},  ' ', {22, 0, 0},  'K', {25, 0, 0, 0}, 0, 21, { 1, 0, 0, 0} },
-	{ "sparc",		{38, 0, 0}, {15, 0, 0}, '\0', { 8,12, 0}, '\0', { 0, 0, 0, 0}, 0, 32, {11, 2, 0, 0} },
-	{ "hppa",		{15, 0, 0}, {30, 0, 0}, '\0', {16, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "mips",		{19, 0, 0}, {36, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 1, 0, 0, 0} },
-	{ "powerpc",		{15, 0, 0}, {29, 0, 0},  'M', {14, 0, 0},  'K', {25,26,42, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "powerpc64",		{15, 0, 0}, {29, 0, 0},  'M', {14, 0, 0},  'K', {25,26,42, 0}, 1, 34, { 0, 0, 0, 0} },
-	{ "arm",		{33,15, 0}, {29,24, 0},  'M', {14, 0, 0}, '\0', { 4, 0, 0, 0}, 1,  0, { 1, 2, 3, 0} },
-	{ "s390",		{37, 0, 0}, {41, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 0, 44, {43, 0, 0, 0} },
-	{ "s390x",		{37, 0, 0}, {41, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 0, 44, {43, 0, 0, 0} },
-	{ "sh",			{18, 0, 0}, {27,29, 0},  'M', {17, 7, 0},  'K', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "m68k",		{ 5, 0, 0}, {28, 0, 0},  'M', {10, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 2, 0, 0, 0} },
-	{ "cris",		{15, 0, 0}, {19, 0, 0}, '\0', { 0, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "frv",		{ 6, 0, 0}, {35, 0, 0},  ' ', { 9, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 2, 0, 0, 0} },
-	{ "vax",		{15, 0, 0}, {20, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 1, 0, 0, 0} },
-	{ "m32r",		{18, 0, 0}, {27, 0, 0},  'M', { 7, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
-	{ "unknown",		{ 0, 0, 0}, { 0, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 0, 0, 0, 0} }
+	{ "i386",		{31,15,30, 0}, {41,30, 0}, '\0', {16, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 2, 0, 0} },
+	{ "x86_64",		{31, 0, 0, 0}, {41, 0, 0}, '\0', {16, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "ia64",		{23, 0, 0, 0}, {40, 0, 0}, '\0', {16, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 1, 0, 0, 0} },
+	{ "alpha",		{19, 0, 0, 0}, {36, 0, 0},  ' ', {22, 0, 0},  'K', {25, 0, 0, 0}, 0, 21, { 1, 0, 0, 0} },
+	{ "sparc",		{38, 0, 0, 0}, {15, 0, 0}, '\0', { 8,12, 0}, '\0', { 0, 0, 0, 0}, 0, 32, {11, 2, 0, 0} },
+	{ "hppa",		{15, 0, 0, 0}, {30, 0, 0}, '\0', {16, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "mips",		{19, 0, 0, 0}, {36, 0, 0}, '\0', {46, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 1, 0, 0, 0} },
+	{ "powerpc",		{15, 0, 0, 0}, {29,30, 0},  'M', {14, 0, 0},  'K', {25,26,42, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "powerpc64",		{15, 0, 0, 0}, {29, 0, 0},  'M', {14, 0, 0},  'K', {25,26,42, 0}, 1, 34, { 0, 0, 0, 0} },
+	{ "arm",		{33,15, 0, 0}, {29,24, 0},  'M', {14, 0, 0}, '\0', { 4, 0, 0, 0}, 1,  0, { 1, 2, 3, 0} },
+	{ "s390",		{37, 0, 0, 0}, {41, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 0, 44, {43, 0, 0, 0} },
+	{ "s390x",		{37, 0, 0, 0}, {41, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 0, 44, {43, 0, 0, 0} },
+	{ "sh",			{18, 0, 0, 0}, {27,29, 0},  'M', {17, 7, 0},  'K', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "m68k",		{ 5, 0, 0, 0}, {28, 0, 0},  'M', {10, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 2, 0, 0, 0} },
+	{ "cris",		{15, 0, 0, 0}, {19, 0, 0}, '\0', { 0, 0, 0},  ' ', {13, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "frv",		{ 6, 0, 0, 0}, {35, 0, 0},  ' ', { 9, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 2, 0, 0, 0} },
+	{ "vax",		{15, 0, 0, 0}, {20, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 1, 0, 0, 0} },
+	{ "m32r",		{18, 0, 0, 0}, {27, 0, 0},  'M', { 7, 0, 0}, '\0', { 0, 0, 0, 0}, 1, 34, { 3, 0, 0, 0} },
+	{ "unknown",		{ 0, 0, 0, 0}, { 0, 0, 0}, '\0', { 0, 0, 0}, '\0', { 0, 0, 0, 0}, 1,  0, { 0, 0, 0, 0} }
 };
 
 #define NUM_ARCHES (19)
@@ -133,7 +135,9 @@ char *__proccpuinfo_key[] = {
 	"vendor_id",			/* 41 */
 	"board l2",			/* 42 */
 	"bogomips per cpu",		/* 43 */
-	"# processors"			/* 44 */
+	"# processors",			/* 44 */
+	"CPU-Series",			/* 45 */
+	"cpu_mhz"			/* 46 */
 };
 
 #if defined(__i386__)
@@ -291,6 +295,9 @@ proccpuinfo *proccpuinfo_read() {
 		}
 	}
 
+	info->cputype = __proccpuinfo_get_cputype();
+	info->version = _VERSION;
+
 	return info;
 }
 
