@@ -41,6 +41,9 @@ int main(int argc, char *argv[]) {
 	printf("cpus\t\t\t: %d processor%c\n",info->cpus, (info->cpus == 1 ? ' ' : 's'));
 	printf("bogomips\t\t: %lf\n",info->bogomips);
 
+	if (info->cputype)
+		printf("cputype\t\t\t: %s\n",info->cputype);
+
 	proccpuinfo_free(info);
 	return 0;
 }
